/******************************************************************
 *
 * Copyright 2015 Samsung Electronics All Rights Reserved.
 *
 *
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ******************************************************************/

#ifndef SIMULATOR_DEVICE_INFO_JNI_H_
#define SIMULATOR_DEVICE_INFO_JNI_H_

#include <jni.h>

#include "simulator_device_info.h"

class JniDeviceInfo
{
    public:
        JniDeviceInfo(JNIEnv *env) : m_env(env) {}
        JniDeviceInfo(const JniDeviceInfo &) = delete;
        JniDeviceInfo &operator=(const JniDeviceInfo &) = delete;
        JniDeviceInfo(const JniDeviceInfo &&) = delete;
        JniDeviceInfo &operator=(const JniDeviceInfo && ) = delete;
        jobject toJava(DeviceInfo &deviceInfo);

    private:
        void setFieldValue(jobject jDeviceInfo, const std::string &fieldName,
                           const std::string &value);

        JNIEnv *m_env;
};

#endif
